// This class provides a template that can be extended to define classes
// that generate HTML for web pages.  Classes that extend this class
// should use it setTitle method to determine the title described by the
// web browser when the page is displayed and the contentPane.add
// method to add WebComponents to the pages.
public class WebPage {
    
    // The title that should be displayed in the browser's title bar
    private String title;
    
    // The collection of web components that should be displayed in the
    // page
    protected WebPane contentPane = new WebPane();
    
    // Create a new, empty web page
    public WebPage( ) {
        this.title = "";
    }
    
    // Set the title to be displayed in the page
    public void setTitle( String title ) {
        this.title = title;
    }
    
    // This method makes it possible for the lazy to simply say "this.add" or
    // even just "add" instead of "contentPane.add".
    public void add( WebComponent c ) {
        contentPane.add( c );
    }
    
    // Return HTML describing the contents that should be displayed
    // by the browswer
    public String toString() {
        String contents = contentPane.toString();
        return "<html><head><title>" + this.title + "</title></head>\n" +
               "<body>\n" + contents + "\n</body></html>\n";
                
    }   
}